/* 
   Copyright (C) 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*
 Persistence of Vision Ray Tracer Scene Description File

 File: tux-sit.pov
 Vers: 3.5
 Date: 08/2003
 Auth: Nicolas Rougier
 Cmd : povray +Itux-sit.pov +w800 +h800 +fn +am2 +P +a0.1
*/

#version 3.5;
#include "colors.inc"
#include "math.inc"
#include "transforms.inc"
#include "spline.inc"
#include "shapes.inc"


// ========================================
//  Notes
// ========================================

// ========================================
//  Switches
// ========================================
#declare use_radiosity = on;

// ========================================
//  Settings
// ========================================
global_settings {
  #if (use_radiosity)
    radiosity {
      pretrace_start 0.08
      pretrace_end 0.005
      count 600
      error_bound 0.05
      nearest_count 5
      recursion_limit 1
      low_error_factor .5
      gray_threshold 0.0
      minimum_reuse 0.015
      brightness 1.0
      adc_bailout 0.01/2
    }
  #end
}

// ========================================
//  Default settings
// ========================================
#default {
  texture {
    #if (use_radiosity)
      finish {
        ambient 0.0
        diffuse 1.0
      }
    #else
      finish {
        ambient    0.1
        diffuse    0.6
      }
    #end
  }
}


// ========================================
//  Lights
// ========================================
light_source {
  <-10, 20, -10>
  color rgb <1.0, 0.99, 0.98>*1
  area_light <10,0,0> <0,0,10> 10,10 circular orient jitter adaptive 2
}

// ========================================
//  Camera
// ========================================
#declare EyePos  = <0, 1,-12>;
#declare EyeLook = <0, 1, 0>;
camera {
  location EyePos
  look_at  EyeLook
  direction 1.5*z
  right     x*image_width/image_height
  angle 20
}

// ========================================
//  Sky
// ========================================
sky_sphere {pigment {rgb 1}}

// ========================================
//  Ground
// ========================================
plane {y,0  texture {pigment {rgb 1} finish {ambient 0.1 diffuse 1}}}
plane {z,100 inverse texture {pigment {rgb 1} finish {ambient 0.1 diffuse 1}}}

// ========================================
//  Spheric to cartesian conversion macro
// ========================================
#macro spheric (rho,theta,phi)
<rho*sin(theta)*sin(phi), rho*cos(theta), rho*sin(theta)*cos(phi)>
#end

// ========================================
// Tux
// ========================================
#include "furtex.inc"

#declare t_fur_black = FurTex (color <1,1,1>*0.10)
#declare t_fur_white = FurTex (color <1,1,1>*1.01)
#declare t_eye_white = texture {pigment{rgb 1}}
#declare t_eye_black = texture {pigment{rgb 0.01} finish {specular 1 roughness 0.005}}
#declare t_beak      = texture {pigment {rgb <1,.55,0>}}
#declare t_tongue    = texture {pigment {rgb <1,0,0>} finish {specular .5 roughness 0.005}}
#declare t_feet      = texture {pigment {rgb <1,.55,0>}}
#include "tux-sit.inc"
object {
  tux
  rotate y*5
}

